@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: SchemaInfo.cpp 883307 2009-11-23 11:35:28Z borisk $
+ * $Id: SchemaInfo.cpp 925236 2010-03-19 14:29:47Z borisk $
  */
 
 // ---------------------------------------------------------------------------
@@ -42,6 +42,7 @@ SchemaInfo::SchemaInfo(const unsigned short elemAttrDefaultQualified,
                        const XMLCh* const schemaURL,
                        const XMLCh* const targetNSURIString,
                        const DOMElement* const root,
+                       XMLScanner* xmlScanner,
                        MemoryManager* const manager)
     : fAdoptInclude(false)
     , fProcessed(false)
@@ -78,6 +79,7 @@ SchemaInfo::SchemaInfo(const unsigned short elemAttrDefaultQualified,
     fCurrentSchemaURL = XMLString::replicate(schemaURL, fMemoryManager);
 	fTargetNSURIString = XMLString::replicate(targetNSURIString, fMemoryManager);
 
+    fValidationContext->setScanner (xmlScanner);
     fValidationContext->setNamespaceScope(fNamespaceScope);
 }
 
